import React, { PropTypes } from 'react';

import { FormattedMessage as Message } from 'react-intl';
import { Link } from 'react-router';
import classNames from 'classnames';

import Userbar from 'components/userbar/Userbar';
import PopupStack from 'components/ui/popup/PopupStack';

import styles from './root.scss';

import messages from './RootPage.intl.json';

/* global process: false */
let DevTools;
if (process.env.NODE_ENV === 'production') {
    DevTools = () => null;
} else {
    DevTools = require('containers/DevTools').default;
}

function RootPage(props) {
    const isRegisterPage = props.location.pathname === '/register';

    document.body.style.overflow = props.isPopupActive ? 'hidden' : '';

    return (
        <div className={styles.root}>
            <div id="view-port" className={classNames(styles.viewPort, {
                [styles.isPopupActive]: props.isPopupActive
            })}>
                <div className={styles.header}>
                    <div className={styles.headerContent}>
                        <Link to="/" className={styles.logo} onClick={props.resetAuth}>
                            <Message {...messages.siteName} />
                        </Link>
                        <div className={styles.userbar}>
                            <Userbar {...props}
                                guestAction={isRegisterPage ? 'login' : 'register'}
                            />
                        </div>
                    </div>
                </div>
                <div className={styles.body}>
                    {props.children}
                </div>
            </div>
            <PopupStack />
            <DevTools />
        </div>
    );
}

RootPage.displayName = 'RootPage';
RootPage.propTypes = {
    location: PropTypes.shape({
        pathname: PropTypes.string
    }).isRequired,
    children: PropTypes.element,
    resetAuth: PropTypes.func.isRequired,
    isPopupActive: PropTypes.bool.isRequired
};

import { connect } from 'react-redux';
import { resetAuth } from 'components/auth/actions';

export default connect((state) => ({
    user: state.user,
    isPopupActive: state.popup.popups.length > 0
}), {
    resetAuth
})(RootPage);
